*WMS* står för [Web Map Service](https://en.wikipedia.org/wiki/Web_Map_Service).
En WMS kan erbjuda ett eller flera kartlager.

**WMS URL**: URL för ett WMS, till exempel
`https://geodienste.hamburg.de/HH_WMS_Gewaesserunterhaltung`.

**WMS Layer**: När du har angett en giltig WMS-URL kan du välja ett av de
dess erbjudna lager här..